buildFONKgpointls: Prepare data for smoothing
Description
From a data frame, builds another data frame. The input data frame must contain values of the canonical parameters of the model and the variables required to construct the smoothed response. Which of the (output) parameters are variable is also determined for later use.Usage
buildFONKgpointls(pointls)
Details
With controls set by the Migraine software, this can operate transformations of parameter space as well as transformations in logarithmic scale (see islogscale). The output frame will then contain values of transformed parameters.