writeFinalInfo: Pretty output, and management of output files

View source: R/writeFinalInfo.R

writeFinalInfoR Documentation

Pretty output, and management of output files

Description

Final code of the R script written by the ‘Migraine’ software (https://gitlab.mbb.univ-montp2.fr/francois/migraine; see main documentation page for the package, for the context). This prints some information, close output files, and beeps to warn that a possibly long computation is finished.

Usage

writeFinalInfo(cleanResu = "")

Arguments

cleanResu

A connection, or a character string naming a file for some nicely formated output. If "" (the default), print to the standard output connection.

Value

returns NULL invisibly.


blackbox documentation built on March 1, 2026, 9:06 a.m.