View source: R/writeFinalInfo.R
| writeFinalInfo | R Documentation |
Final code of the R script written by the ‘Migraine’ software (https://gitlab.mbb.univ-montp2.fr/francois/migraine; see main documentation page for the package, for the context). This prints some information, close output files, and beeps to warn that a possibly long computation is finished.
writeFinalInfo(cleanResu = "")
cleanResu |
A connection, or a character string naming a file for some nicely formated output. If |
returns NULL invisibly.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.