Learn R Programming

blackbox (version 1.1.54)

writeFinalInfo: Pretty output, and management of output files

Description

Final code of the R script written by the ‘Migraine’ software (https://gitlab.mbb.univ-montp2.fr/francois/migraine; see main documentation page for the package, for the context). This prints some information, close output files, and beeps to warn that a possibly long computation is finished.

Usage

writeFinalInfo(cleanResu = "")

Value

returns NULL invisibly.

Arguments

cleanResu

A connection, or a character string naming a file for some nicely formated output. If "" (the default), print to the standard output connection.