Final code of the R script written by the ‘Migraine’ software (https://gitlab.mbb.univ-montp2.fr/francois/migraine; see main documentation page for the package, for the context). This prints some information, close output files, and beeps to warn that a possibly long computation is finished.
writeFinalInfo(cleanResu = "")returns NULL invisibly.
A connection, or a character string naming a file for some nicely formated output. If "" (the default), print to the standard output connection.